@@ -17,7 +17,7 @@ use warnings;
 package MongoDB::_Topology;
 
 use version;
-our $VERSION = 'v2.0.1';
+our $VERSION = 'v2.0.2';
 
 use Moo;
 use BSON;
@@ -597,6 +597,8 @@ sub _check_wire_versions {
         my ( $server_min_wire_version, $server_max_wire_version ) =
           @{ $server->is_master }{qw/minWireVersion maxWireVersion/};
 
+        # set to 0 as could be undefined. 0 is the equivalent to missing, and
+        # also kept as 0 for legacy compatibility.
         $server_max_wire_version = 0 unless defined $server_max_wire_version;
         $server_min_wire_version = 0 unless defined $server_min_wire_version;
 
@@ -1200,8 +1202,9 @@ sub _update_rs_with_primary_from_member {
         $self->_remove_server($new_server);
     }
 
-    # require 'me' that matches expected address
-    if ( $new_server->me && $new_server->me ne $new_server->address ) {
+    # require 'me' that matches expected address.
+    # check is case insensitive
+    if ( $new_server->me && lc $new_server->me ne $new_server->address ) {
         $self->_remove_server($new_server);
         $self->_check_for_primary;
         return;
